==> skrooge-0.2.6.tar.gz: skrooge-0.2.6/skrooge_operation/skgsplittabledelegate.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSPLITTABLEDELEGATE_H
#define SKGSPLITTABLEDELEGATE_H
/** @file
* This file is Skrooge plugin for bank management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/

#include <QItemDelegate>

class SKGDocument;

/**
 * This file is Skrooge plugin for operation management
 */
class SKGSplitTableDelegate : public QItemDelegate
{
        Q_OBJECT
public:
        /**
         * Default Constructor
         */
        explicit SKGSplitTableDelegate(QObject* parent = 0, const SKGDocument* iDoc=NULL);

        /**
         * Default Destructor
         */
        virtual ~SKGSplitTableDelegate();

        /**
         * Returns the widget used to edit the item specified by index for editing.
         * The parent widget and style option are used to control how the editor widget appears.
         * @param parent perant widget
         * @param option options
         * @param index index
         * @return the widget
         */
        QWidget *createEditor(QWidget *parent,
                              const QStyleOptionViewItem & option ,
                              const QModelIndex & index ) const;

private:
        Q_DISABLE_COPY(SKGSplitTableDelegate);

        SKGDocument* document;
};

#endif // SKGSPLITTABLEDELEGATE_H

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skrooge_operation/skgsplittabledelegate.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSPLITTABLEDELEGATE_H
#define SKGSPLITTABLEDELEGATE_H
/** @file
* This file is Skrooge plugin for bank management.
*
* @author Stephane MANKOWSKI / Guillaume DE BURE
*/

#include <QItemDelegate>

class SKGDocument;

/**
 * This file is Skrooge plugin for operation management
 */
class SKGSplitTableDelegate : public QItemDelegate
{
        Q_OBJECT
public:
        /**
         * Default Constructor
         */
        explicit SKGSplitTableDelegate(QObject* parent = 0, const SKGDocument* iDoc=NULL);

        /**
         * Default Destructor
         */
        virtual ~SKGSplitTableDelegate();

        /**
         * Returns the widget used to edit the item specified by index for editing.
         * The parent widget and style option are used to control how the editor widget appears.
         * @param parent parant widget
         * @param option options
         * @param index index
         * @return the widget
         */
        QWidget *createEditor(QWidget *parent,
                              const QStyleOptionViewItem & option ,
                              const QModelIndex & index ) const;

        /**
         * Set the data to be shown in the delegate. For the quantity column,
         * We pass the text value. This allows the user to correct an invalid 
         * expression without having to retype everything.
         * @param editor
         * @param index
         */
        void setEditorData(QWidget *editor, const QModelIndex &index) const;
           
        /**
         * Get the data to be shown in the model. For the quantity column,
         * We pass the text value. If the entered expression was incorrect,
         * we display it in red so that the user can see it is wrong and
         * correct it
         * @param editor
         * @param model
         * @param index
         */
        void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const;                    
  
private:
        Q_DISABLE_COPY(SKGSplitTableDelegate);

        SKGDocument* document;
};

#endif // SKGSPLITTABLEDELEGATE_H
